@@ -20,14 +20,18 @@ class Drawer(QWidget):
 
         self.__widget = widget
 
+        align = ''
+
         # init size animation
         self.__sizeAnimation = ''
         if orientation == Qt.Horizontal:
             self.__widget.setFixedWidth(0)
+            align = Qt.AlignLeft
             self.__sizeAnimation = QPropertyAnimation(self, b"width")
             self.__sizeAnimation.valueChanged.connect(self.__widget.setFixedWidth)
         else:
             self.__widget.setFixedHeight(0)
+            align = Qt.AlignTop
             self.__sizeAnimation = QPropertyAnimation(self, b"height")
             self.__sizeAnimation.valueChanged.connect(self.__widget.setFixedHeight)
         self.__sizeAnimation.setStartValue(0)
@@ -35,19 +39,27 @@ class Drawer(QWidget):
         self.__sizeAnimation.setEndValue(200)  # default end value
 
         # init opacity animation
-        self.__opacityAnimation = ''
-        self.__widget.setGraphicsEffect(QGraphicsOpacityEffect(opacity=0.0))
         self.__opacityAnimation = QPropertyAnimation(self, b"opacity")
+        self.__widget.setGraphicsEffect(QGraphicsOpacityEffect(opacity=0.0))
         self.__opacityAnimation.valueChanged.connect(self.__setOpacity)
 
         self.__opacityAnimation.setStartValue(0.0)
         self.__opacityAnimation.setDuration(200)
         self.__opacityAnimation.setEndValue(1.0)
 
+        # todo init parent opacity animation
+        # self.__parentOpacityAnimation = QPropertyAnimation(self, b"parentopacity")
+        # self.__parentOpacityAnimation.valueChanged.connect(self.__setParentOpacity)
+
+        # self.__parentOpacityAnimation.setStartValue(1.0)
+        # self.__parentOpacityAnimation.setDuration(200)
+        # self.__parentOpacityAnimation.setEndValue(0.8)
+
         lay = QGridLayout()
         lay.addWidget(self.__btn, 0, 0, 1, 1, Qt.AlignTop | Qt.AlignLeft)
-        lay.addWidget(self.__widget, 0, 0, 1, 2)
+        lay.addWidget(self.__widget, 0, 0, 1, 2, align)
         lay.setSpacing(0)
+        lay.setContentsMargins(0, 0, 0, 0)
 
         self.setLayout(lay)
 
@@ -55,21 +67,29 @@ class Drawer(QWidget):
         if f:
             self.__sizeAnimation.setDirection(QAbstractAnimation.Forward)
             self.__opacityAnimation.setDirection(QAbstractAnimation.Forward)
+            # self.__parentOpacityAnimation.setDirection(QAbstractAnimation.Forward)
             self.__btn.hide()
         else:
             self.__sizeAnimation.setDirection(QAbstractAnimation.Backward)
             self.__opacityAnimation.setDirection(QAbstractAnimation.Backward)
+            # self.__parentOpacityAnimation.setDirection(QAbstractAnimation.Backward)
             self.__btn.show()
-        self.__opacityAnimation.start()
         self.__sizeAnimation.start()
+        self.__opacityAnimation.start()
+        # self.__parentOpacityAnimation.start()
 
     def __setOpacity(self, opacity):
         opacity_effect = QGraphicsOpacityEffect(opacity=opacity)
         self.__widget.setGraphicsEffect(opacity_effect)
 
+    # def __setParentOpacity(self, opacity):
+    #     opacity_effect = QGraphicsOpacityEffect(opacity=opacity)
+    #     self.__parent.setGraphicsEffect(opacity_effect)
+
     def setDuration(self, msecs):
         self.__sizeAnimation.setDuration(msecs)
         self.__opacityAnimation.setDuration(msecs)
+        # self.__parentOpacityAnimation.setDuration(msecs)
 
     def setEndValue(self, value):
         self.__sizeAnimation.setEndValue(value)
